@@ -33,12 +33,7 @@ class RequestHandler(web.RequestHandler):
             _executed(error)
 
 
-class JSONRequestHandler(RequestHandler):
-    request_class = hens.JSONRequest
-    response_class = hens.JSONResponse
-
-
-class JSONClient(hens.JSONClient):
+class Client(hens.Client):
     def init(self, url, **kwargs):
         self.url = url
         self.http_client = httpclient.HTTPClient()
@@ -54,4 +49,19 @@ class JSONClient(hens.JSONClient):
         return raw_response
 
 
+class JSONRequestHandler(RequestHandler):
+    request_class = hens.JSONRequest
+    response_class = hens.JSONResponse
 
+
+class JSONClient(hens.JSONClient, Client):
+    pass
+
+
+class cPickleRequestHandler(RequestHandler):
+    request_class = hens.cPickleRequest
+    response_class = hens.cPickleResponse
+
+
+class cPickleClient(hens.cPickleClient, Client):
+    pass
